==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CategoryHighlightLayerDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnnotationLayerDescription } from "./AnnotationLayerDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var CategoryHighlightLayerDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryHighlightLayerDescription, _super);
    function CategoryHighlightLayerDescription() {
        var _this = _super.call(this) || this;
        _this.di = null;
        _this.de = false;
        _this.dg = 0;
        return _this;
    }
    CategoryHighlightLayerDescription.prototype.get_type = function () {
        return "CategoryHighlightLayer";
    };
    Object.defineProperty(CategoryHighlightLayerDescription.prototype, "targetAxisRef", {
        get: function () {
            return this.di;
        },
        set: function (a) {
            this.di = a;
            this.e("TargetAxisRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CategoryHighlightLayerDescription.prototype, "useInterpolation", {
        get: function () {
            return this.de;
        },
        set: function (a) {
            this.de = a;
            this.e("UseInterpolation");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CategoryHighlightLayerDescription.prototype, "bandHighlightWidth", {
        get: function () {
            return this.dg;
        },
        set: function (a) {
            this.dg = a;
            this.e("BandHighlightWidth");
        },
        enumerable: false,
        configurable: true
    });
    CategoryHighlightLayerDescription.$t = markType(CategoryHighlightLayerDescription, 'CategoryHighlightLayerDescription', AnnotationLayerDescription.$);
    return CategoryHighlightLayerDescription;
}(AnnotationLayerDescription));
export { CategoryHighlightLayerDescription };

==> igniteui-react-core-19.0.0.tgz: package/esm5/lib/CategoryHighlightLayerDescription.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { AnnotationLayerDescription } from "./AnnotationLayerDescription";
import { markType } from "./type";
/**
 * @hidden
 */
var CategoryHighlightLayerDescription = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CategoryHighlightLayerDescription, _super);
    function CategoryHighlightLayerDescription() {
        var _this = _super.call(this) || this;
        _this.gj = null;
        _this.gf = false;
        _this.gh = 0;
        return _this;
    }
    CategoryHighlightLayerDescription.prototype.get_type = function () {
        return "CategoryHighlightLayer";
    };
    Object.defineProperty(CategoryHighlightLayerDescription.prototype, "targetAxisRef", {
        get: function () {
            return this.gj;
        },
        set: function (a) {
            this.gj = a;
            this.g("TargetAxisRef");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CategoryHighlightLayerDescription.prototype, "useInterpolation", {
        get: function () {
            return this.gf;
        },
        set: function (a) {
            this.gf = a;
            this.g("UseInterpolation");
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(CategoryHighlightLayerDescription.prototype, "bandHighlightWidth", {
        get: function () {
            return this.gh;
        },
        set: function (a) {
            this.gh = a;
            this.g("BandHighlightWidth");
        },
        enumerable: false,
        configurable: true
    });
    CategoryHighlightLayerDescription.$t = markType(CategoryHighlightLayerDescription, 'CategoryHighlightLayerDescription', AnnotationLayerDescription.$);
    return CategoryHighlightLayerDescription;
}(AnnotationLayerDescription));
export { CategoryHighlightLayerDescription };
